Learn how to install the program using any of the following methods:

- [System-wide installation via uv](system-wide-installation-via-uv.md) - This is my recommended method for most users as you can easily run the program from your terminal anywhere.
- [Isolated installation via uv](isolated-installation-via-uv.md) - Preferred method for those who will use this program for their scripts.
- [System-wide installation via pip](system-wide-installation-via-pip.md) - Alternative method from the first ones, but may cause issues related to system's package dependencies.
